@@ -12,14 +12,14 @@ test_tbl_time <- as_tbl_time(test_time, date)
 # Tests
 
 test_that("select works as expected", {
-  expect_equal(select(test_tbl_time, date, value),
-               select(test_time, date, value))
+  expect_equal(dplyr::select(test_tbl_time, date, value),
+               dplyr::select(test_time, date, value))
 })
 
 test_that("tbl_time class is retained", {
-  expect_is(select(test_tbl_time, date, value), "tbl_time")
+  expect_is(dplyr::select(test_tbl_time, date, value), "tbl_time")
 })
 
 test_that("tbl_time class is lost without date", {
-  expect_false("tbl_time" %in% class(select(test_tbl_time, value)))
+  expect_false("tbl_time" %in% class(dplyr::select(test_tbl_time, value)))
 })
